"""
Mock of Python pyparsing as cPyparsing for the sake of timing comparison.
"""

print("cPyparsing -> pyparsing mock loaded")

from pyparsing import *
from pyparsing import __version__, _trim_arity
from pyparsing import pyparsing_test
